@@ -10,10 +10,11 @@ from vorta.borg.version import BorgVersionJob
 from vorta.borg.break_lock import BorgBreakJob
 from vorta.config import TEMP_DIR, PROFILE_BOOTSTRAP_FILE
 from vorta.i18n import init_translations, translate
-from vorta.models import BackupProfileModel, SettingsModel, cleanup_db
+from vorta.store.models import BackupProfileModel, SettingsModel
+from vorta.store.connection import cleanup_db
 from vorta.qt_single_application import QtSingleApplication
 from vorta.scheduler import VortaScheduler
-from vorta.borg.job_scheduler import JobsManager
+from vorta.borg.jobs_manager import JobsManager
 from vorta.tray_menu import TrayMenu
 from vorta.utils import borg_compat, parse_args
 from vorta.views.main_window import MainWindow
@@ -38,6 +39,7 @@ class VortaApp(QtSingleApplication):
     backup_cancelled_event = QtCore.pyqtSignal()
     backup_log_event = QtCore.pyqtSignal(str, dict)
     backup_progress_event = QtCore.pyqtSignal(str)
+    check_failed_event = QtCore.pyqtSignal(str)
 
     def __init__(self, args_raw, single_app=False):
         super().__init__(APP_ID, args_raw)
@@ -57,6 +59,7 @@ class VortaApp(QtSingleApplication):
         init_translations(self)
 
         self.setQuitOnLastWindowClosed(False)
+        self.jobs_manager = JobsManager()
         self.scheduler = VortaScheduler()
 
         self.setApplicationName("Vorta")
@@ -77,6 +80,7 @@ class VortaApp(QtSingleApplication):
         self.backup_finished_event.connect(self.backup_finished_event_response)
         self.backup_cancelled_event.connect(self.backup_cancelled_event_response)
         self.message_received_event.connect(self.message_received_event_response)
+        self.check_failed_event.connect(self.check_failed_response)
         self.backup_log_event.connect(self.react_to_log)
         self.aboutToQuit.connect(self.quit_app_action)
         self.set_borg_details_action()
@@ -119,7 +123,7 @@ class VortaApp(QtSingleApplication):
         msg = BorgCreateJob.prepare(profile)
         if msg['ok']:
             job = BorgCreateJob(msg['cmd'], msg, profile.repo.id)
-            self.scheduler.jobs_manager.add_job(job)
+            self.jobs_manager.add_job(job)
         else:
             notifier = VortaNotifications.pick()
             notifier.deliver(self.tr('Vorta Backup'), translate('messages', msg['message']), level='error')
@@ -141,11 +145,11 @@ class VortaApp(QtSingleApplication):
         self.tray.set_tray_icon(active=True)
 
     def backup_finished_event_response(self):
-        if not JobsManager.is_worker_running():
+        if not self.jobs_manager.is_worker_running():
             self.tray.set_tray_icon()
 
     def backup_cancelled_event_response(self):
-        self.scheduler.cancel_all_jobs()
+        self.jobs_manager.cancel_all_jobs()
         self.tray.set_tray_icon()
 
     def message_received_event_response(self, message):
@@ -153,7 +157,7 @@ class VortaApp(QtSingleApplication):
             self.open_main_window_action()
         elif message.startswith("create"):
             message = message[7:]  # Remove create
-            if JobsManager.is_worker_running():
+            if self.jobs_manager.is_worker_running():
                 logger.warning("Cannot run while backups are already running")
             else:
                 self.create_backups_cmdline(message)
@@ -164,9 +168,9 @@ class VortaApp(QtSingleApplication):
         if not params['ok']:
             self._alert_missing_borg()
             return
-        job = BorgVersionJob(params['cmd'], params, parent=self)
+        job = BorgVersionJob(params['cmd'], params)
         job.result.connect(self.set_borg_details_result)
-        self.scheduler.jobs_manager.add_job(job)
+        self.jobs_manager.add_job(job)
 
     def set_borg_details_result(self, result):
         """
@@ -248,8 +252,8 @@ class VortaApp(QtSingleApplication):
         if not params['ok']:
             self.backup_progress_event.emit(params['message'])
             return
-        job = BorgBreakJob(params['cmd'], params, parent=self)
-        self.scheduler.jobs_manager.add_job(job)
+        job = BorgBreakJob(params['cmd'], params)
+        self.jobs_manager.add_job(job)
 
     def bootstrap_profile(self, bootstrap_file=PROFILE_BOOTSTRAP_FILE):
         """
@@ -283,3 +287,12 @@ class VortaApp(QtSingleApplication):
         if BackupProfileModel.select().count() == 0:
             default_profile = BackupProfileModel(name='Default')
             default_profile.save()
+
+    def check_failed_response(self, repo_url):
+        msg = QMessageBox()
+        msg.setIcon(QMessageBox.Critical)
+        msg.setStandardButtons(QMessageBox.Ok)
+        msg.setWindowTitle(self.tr('Repo Check Failed'))
+        msg.setText(self.tr('Repository data check for repo %s failed') % repo_url)
+        msg.setInformativeText(self.tr('Repair or recreate the repository soon to avoid missing data.'))
+        msg.exec()
